@@ -22,7 +22,7 @@
 #include "SopranoModelTest.h"
 #include "stringpool.h"
 
-#include <soprano/soprano.h>
+#include "soprano.h"
 
 #include <QtTest/QTest>
 #include <QtCore/QList>
@@ -32,6 +32,7 @@
 #include <QtCore/QTime>
 #include <QtCore/QUrl>
 #include <QtCore/QUuid>
+#include <QtCore/QCoreApplication>
 #include <QtTest/QSignalSpy>
 
 
@@ -266,7 +267,6 @@ void SopranoModelTest::testListStatements()
     while( it4.next() ) {
         ++cnt;
         Statement st = *it4;
-
         QVERIFY( statements.contains( st ) || st == m_st1 || st == m_st2 || st == m_st3 || st == m_st4 );
     }
 
